@@ -2,8 +2,9 @@
 # encoding=utf-8
 # maintainer: rgaudin
 
+import sys
 from django.conf import settings
-from django.core.management.base import BaseCommand, CommandError
+from django.core.management.base import BaseCommand
 from django.utils import translation
 
 from nosmsd.nosmsd_incoming import handle as nohandle
