@@ -251,7 +251,7 @@ class SentItems(models.Model):
         return self.status
 
     def total_parts(self):
-        return SentItems.objects.filter(id=self.id).count()
+        return SentItems.raw.filter(id=self.id).count()
 
     def is_multipart(self):
         return self.total_parts() > 1
